Package: netmeta
Title: Network Meta-Analysis using Frequentist Methods
Version: 3.6-1
Date: 2026-06-19
Depends: R (>= 4.0.0), meta (>= 8.5-0)
Imports: Matrix, metafor, MASS, mvtnorm, magic, igraph, ggplot2,
        colorspace, grid, dplyr, magrittr, methods, stringr, tidyr,
        ggrepel
Suggests: Rgraphviz, graph, rgl, gridExtra, tictoc, writexl, R.rsp,
        cccp, brglm2, crossnma, gemtc, rmarkdown, knitr
Authors@R: c(person("Gerta", "Rücker",
                    role = "aut",
                    comment = c(ORCID = "0000-0002-2192-2560")),
             person("Ulrike", "Krahn",
                    role = "aut"),
             person("Jochem", "König",
                    role = "aut",
                    comment = c(ORCID = "0000-0003-4683-0360")),
             person("Orestis", "Efthimiou",
                    role = "aut",
                    comment = c(ORCID = "0000-0002-0955-7572")),
             person("Annabel", "Davies",
                    role = "aut",
                    comment = c(ORCID = "0000-0003-2320-7701")),
             person("Theodoros", "Papakonstantinou",
                    role = "aut",
                    comment = c(ORCID = "0000-0002-6630-6817")),
             person("Theodoros", "Evrenoglou",
                    role = "ctb",
                    comment = c(ORCID = "0000-0003-3336-8058")),
             person("Krzysztof", "Ciomek",
                    role = "ctb",
                    comment = c(ORCID = "0000-0002-2293-2146",
                    paste("Author of the original MIT-licensed",
                          "R package hasseDiagram"))),
             person("Nana-adjoa", "Kwarteng",
                    role = "ctb",
                    comment = c(ORCID = "0009-0009-0502-6887")),
             person("Guido", "Schwarzer",
                    role = c("aut", "cre"),
                    email = "guido.schwarzer@uniklinik-freiburg.de",
                    comment = c(ORCID = "0000-0001-6214-9087")))
URL: https://github.com/guido-s/netmeta
Description: A comprehensive set of functions providing frequentist methods for network meta-analysis (Balduzzi et al., 2023) <doi:10.18637/jss.v106.i02> and supporting Schwarzer et al. (2015) <doi:10.1007/978-3-319-21416-0>, Chapter 8 "Network Meta-Analysis":
 - frequentist network meta-analysis following Rücker (2012) <doi:10.1002/jrsm.1058>;
 - additive network meta-analysis for combinations of treatments (Rücker et al., 2020) <doi:10.1002/bimj.201800167>;
 - network meta-analysis of binary data using the Mantel-Haenszel or non-central hypergeometric distribution method (Efthimiou et al., 2019) <doi:10.1002/sim.8158>, or penalised logistic regression (Evrenoglou et al., 2022) <doi:10.1002/sim.9562>;
 - rankograms and ranking of treatments by the Surface under the cumulative ranking curve (SUCRA) (Salanti et al., 2013) <doi:10.1016/j.jclinepi.2010.03.016>;
 - ranking of treatments using P-scores (frequentist analogue of SUCRAs without resampling) according to Rücker & Schwarzer (2015) <doi:10.1186/s12874-015-0060-8>;
 - split direct and indirect evidence to check consistency (Dias et al., 2010) <doi:10.1002/sim.3767>, (Efthimiou et al., 2019) <doi:10.1002/sim.8158>;
 - scatter plot to visualize local inconsistency (Wilson et al., 2026) <doi:10.1017/rsm.2026.10082>;
 - league table with network meta-analysis results;
 - 'comparison-adjusted' funnel plot (Chaimani & Salanti, 2012) <doi:10.1002/jrsm.57>;
 - net heat plot and design-based decomposition of Cochran's Q according to Krahn et al. (2013) <doi:10.1186/1471-2288-13-35>;
 - measures characterizing the flow of evidence between two treatments by König et al. (2013) <doi:10.1002/sim.6001>;
 - automated drawing of network graphs described in Rücker & Schwarzer (2016) <doi:10.1002/jrsm.1143>;
 - partial order of treatment rankings ('poset') and Hasse diagram for 'poset' (Carlsen & Bruggemann, 2014) <doi:10.1002/cem.2569>; (Rücker & Schwarzer, 2017) <doi:10.1002/jrsm.1270>;
 - contribution matrix as described in Papakonstantinou et al. (2018) <doi:10.12688/f1000research.14770.3> and Davies et al. (2022) <doi:10.1002/sim.9346>;
 - network meta-regression with a single continuous or binary covariate (Kwarteng et al., 2026) <doi:10.21203/rs.3.rs-8235913/v1>;
 - subgroup network meta-analysis.
License: GPL (>= 2) | file LICENSE
Encoding: UTF-8
VignetteBuilder: R.rsp, knitr
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-06-19 16:53:32 UTC; sc
Author: Gerta Rücker [aut] (ORCID: <https://orcid.org/0000-0002-2192-2560>),
  Ulrike Krahn [aut],
  Jochem König [aut] (ORCID: <https://orcid.org/0000-0003-4683-0360>),
  Orestis Efthimiou [aut] (ORCID:
    <https://orcid.org/0000-0002-0955-7572>),
  Annabel Davies [aut] (ORCID: <https://orcid.org/0000-0003-2320-7701>),
  Theodoros Papakonstantinou [aut] (ORCID:
    <https://orcid.org/0000-0002-6630-6817>),
  Theodoros Evrenoglou [ctb] (ORCID:
    <https://orcid.org/0000-0003-3336-8058>),
  Krzysztof Ciomek [ctb] (ORCID: <https://orcid.org/0000-0002-2293-2146>,
    Author of the original MIT-licensed R package hasseDiagram),
  Nana-adjoa Kwarteng [ctb] (ORCID:
    <https://orcid.org/0009-0009-0502-6887>),
  Guido Schwarzer [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-6214-9087>)
Maintainer: Guido Schwarzer <guido.schwarzer@uniklinik-freiburg.de>
Repository: CRAN
Date/Publication: 2026-06-20 05:10:21 UTC
Built: R 4.5.2; ; 2026-06-20 06:48:44 UTC; unix
