# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,netconnection)
S3method(as.data.frame,netmeta)
S3method(baujat,netpairwise)
S3method(createC,default)
S3method(createC,matrix)
S3method(createC,netcomb)
S3method(createC,netconnection)
S3method(createC,netmeta)
S3method(drawDetails,hasseGrob)
S3method(forest,netbind)
S3method(forest,netcomb)
S3method(forest,netcomparison)
S3method(forest,netcomplex)
S3method(forest,netmeta)
S3method(forest,netpairwise)
S3method(forest,netsplit)
S3method(forest,subgroup.netmeta)
S3method(funnel,netmeta)
S3method(funnel,netpairwise)
S3method(hasse,netposet)
S3method(heatplot,netmeta)
S3method(merge,pairwise)
S3method(metabias,netmeta)
S3method(metabias,netpairwise)
S3method(metacum,netpairwise)
S3method(metainf,netpairwise)
S3method(metareg,netpairwise)
S3method(netconnection,default)
S3method(netconnection,netcomb)
S3method(netconnection,netmeta)
S3method(netconnection,pairwise)
S3method(netdistance,default)
S3method(netdistance,netcomb)
S3method(netdistance,netconnection)
S3method(netdistance,netmeta)
S3method(netgraph,discomb)
S3method(netgraph,netcomb)
S3method(netgraph,netconnection)
S3method(netgraph,netimpact)
S3method(netgraph,netmeta)
S3method(netmetareg,default)
S3method(netmetareg,netmeta)
S3method(netpairwise,netmeta)
S3method(netpairwise,netmetabin)
S3method(plot,netbind)
S3method(plot,netcomb)
S3method(plot,netcomparison)
S3method(plot,netcomplex)
S3method(plot,netmeta)
S3method(plot,netpairwise)
S3method(plot,netposet)
S3method(plot,netrank)
S3method(plot,netsplit)
S3method(plot,rankogram)
S3method(plot,subgroup.netmeta)
S3method(print,decomp.design)
S3method(print,hatmatrix)
S3method(print,metabias.netpairwise)
S3method(print,metacum.netpairwise)
S3method(print,metainf.netpairwise)
S3method(print,metareg.netpairwise)
S3method(print,netbind)
S3method(print,netcomb)
S3method(print,netcomparison)
S3method(print,netcomplex)
S3method(print,netconnection)
S3method(print,netcontrib)
S3method(print,netdistance)
S3method(print,netimpact)
S3method(print,netleague)
S3method(print,netmeta)
S3method(print,netmetareg)
S3method(print,netpairwise)
S3method(print,netposet)
S3method(print,netrank)
S3method(print,netsplit)
S3method(print,nettable)
S3method(print,plot.netsplit)
S3method(print,rankogram)
S3method(print,subgroup.netmeta)
S3method(print,summary.netcomb)
S3method(print,summary.netconnection)
S3method(print,summary.netmeta)
S3method(print,summary.netmetareg)
S3method(print,summary.netpairwise)
S3method(print,summary.rankogram)
S3method(print,trimfill.netpairwise)
S3method(radial,netmeta)
S3method(radial,netpairwise)
S3method(rankogram,default)
S3method(rankogram,netmeta)
S3method(subgroup,netmeta)
S3method(summary,netcomb)
S3method(summary,netconnection)
S3method(summary,netmeta)
S3method(summary,netmetareg)
S3method(summary,netpairwise)
S3method(summary,rankogram)
S3method(trimfill,netpairwise)
export(combinations)
export(comps)
export(createC)
export(crossnma2netmeta)
export(decomp.design)
export(discomb)
export(gemtc2netmeta)
export(hasse)
export(hatmatrix)
export(heatplot)
export(invmat)
export(netbind)
export(netcomb)
export(netcomparison)
export(netcomplex)
export(netconnection)
export(netcontrib)
export(netdistance)
export(netgraph)
export(netheat)
export(netimpact)
export(netleague)
export(netmatrix)
export(netmeasures)
export(netmeta)
export(netmetabin)
export(netmetareg)
export(netpairwise)
export(netposet)
export(netrank)
export(netsplit)
export(nettable)
export(rankogram)
export(settings.netmeta)
export(subgroup)
export(treats)
importFrom(MASS,ginv)
importFrom(Matrix,bdiag)
importFrom(colorspace,choose_palette)
importFrom(colorspace,diverge_hcl)
importFrom(colorspace,diverge_hsv)
importFrom(colorspace,heat_hcl)
importFrom(colorspace,rainbow_hcl)
importFrom(colorspace,sequential_hcl)
importFrom(colorspace,terrain_hcl)
importFrom(dplyr,"%>%")
importFrom(dplyr,bind_rows)
importFrom(dplyr,case_when)
importFrom(dplyr,count)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,if_else)
importFrom(dplyr,inner_join)
importFrom(dplyr,last_col)
importFrom(dplyr,mutate)
importFrom(dplyr,pull)
importFrom(dplyr,relocate)
importFrom(dplyr,rename)
importFrom(dplyr,select)
importFrom(dplyr,starts_with)
importFrom(dplyr,summarise)
importFrom(ggplot2,aes)
importFrom(ggplot2,coord_cartesian)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_line)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,expand_limits)
importFrom(ggplot2,geom_abline)
importFrom(ggplot2,geom_col)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_step)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,geom_tile)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,guide_legend)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,margin)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_fill_gradient2)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_x_discrete)
importFrom(ggplot2,scale_y_discrete)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_classic)
importFrom(ggplot2,theme_dark)
importFrom(ggplot2,xlab)
importFrom(ggplot2,ylab)
importFrom(ggrepel,geom_text_repel)
importFrom(grDevices,col2rgb)
importFrom(grDevices,colours)
importFrom(grDevices,heat.colors)
importFrom(grDevices,rainbow)
importFrom(grDevices,rgb)
importFrom(grDevices,xy.coords)
importFrom(graphics,axis)
importFrom(graphics,box)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,rect)
importFrom(graphics,strheight)
importFrom(graphics,strwidth)
importFrom(graphics,text)
importFrom(graphics,title)
importFrom(grid,arrow)
importFrom(grid,convertHeight)
importFrom(grid,convertWidth)
importFrom(grid,convertX)
importFrom(grid,convertY)
importFrom(grid,drawDetails)
importFrom(grid,gpar)
importFrom(grid,grid.clip)
importFrom(grid,grid.draw)
importFrom(grid,grid.lines)
importFrom(grid,grid.newpage)
importFrom(grid,grid.rect)
importFrom(grid,grid.roundrect)
importFrom(grid,grid.text)
importFrom(grid,grob)
importFrom(grid,popViewport)
importFrom(grid,pushViewport)
importFrom(grid,stringWidth)
importFrom(grid,unit)
importFrom(grid,viewport)
importFrom(igraph,"E<-")
importFrom(igraph,"V<-")
importFrom(igraph,E)
importFrom(igraph,V)
importFrom(igraph,all_simple_paths)
importFrom(igraph,delete_edges)
importFrom(igraph,get.shortest.paths)
importFrom(igraph,graph_from_adjacency_matrix)
importFrom(igraph,graph_from_edgelist)
importFrom(igraph,gsize)
importFrom(igraph,head_of)
importFrom(igraph,set_edge_attr)
importFrom(igraph,set_vertex_attr)
importFrom(igraph,tail_of)
importFrom(magic,adiag)
importFrom(magrittr,"%<>%")
importFrom(meta,backtransf)
importFrom(meta,baujat)
importFrom(meta,ci)
importFrom(meta,cilayout)
importFrom(meta,forest)
importFrom(meta,funnel)
importFrom(meta,gs)
importFrom(meta,longarm)
importFrom(meta,metabias)
importFrom(meta,metabin)
importFrom(meta,metacont)
importFrom(meta,metacum)
importFrom(meta,metagen)
importFrom(meta,metainc)
importFrom(meta,metainf)
importFrom(meta,metareg)
importFrom(meta,pairwise)
importFrom(meta,radial)
importFrom(meta,settings.meta)
importFrom(meta,trimfill)
importFrom(metafor,bldiag)
importFrom(metafor,contrmat)
importFrom(metafor,rma.mv)
importFrom(metafor,rma.uni)
importFrom(methods,as)
importFrom(mvtnorm,rmvnorm)
importFrom(stats,aggregate)
importFrom(stats,as.formula)
importFrom(stats,binomial)
importFrom(stats,coef)
importFrom(stats,dist)
importFrom(stats,fitted)
importFrom(stats,glm)
importFrom(stats,hclust)
importFrom(stats,model.matrix)
importFrom(stats,optim)
importFrom(stats,optimize)
importFrom(stats,pchisq)
importFrom(stats,prcomp)
importFrom(stats,quantile)
importFrom(stats,relevel)
importFrom(stats,reshape)
importFrom(stats,residuals)
importFrom(stats,rnorm)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,update)
importFrom(stats,vcov)
importFrom(stringr,str_length)
importFrom(tidyr,pivot_longer)
importFrom(utils,capture.output)
importFrom(utils,installed.packages)
importFrom(utils,packageDescription)
importFrom(utils,packageVersion)
