% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/createC.R
\name{createC}
\alias{createC}
\alias{createC.matrix}
\alias{createC.netcomb}
\alias{createC.netmeta}
\alias{createC.netconnection}
\alias{createC.default}
\alias{combinations}
\title{Auxiliary functions for component network meta-analysis}
\usage{
createC(x, ...)

\method{createC}{matrix}(
  x,
  comb.ia,
  inactive = NULL,
  sep.comps = gs("sep.comps"),
  sep.ia = gs("sep.ia"),
  ...
)

\method{createC}{netcomb}(x, comb.ia = NULL, inactive = NULL, sep.ia = x$sep.ia, ...)

\method{createC}{netmeta}(x, inactive = NULL, sep.comps = gs("sep.comps"), ...)

\method{createC}{netconnection}(x, inactive = NULL, sep.comps = gs("sep.comps"), ...)

\method{createC}{default}(x, n = 1, ...)

combinations(x, n = NULL)
}
\arguments{
\item{x}{A \code{\link{netcomb}}, \code{\link{netmeta}} or
\code{\link{netconnection}} object, a matrix or the number of components.}

\item{\dots}{Additional arguments.}

\item{comb.ia}{A character vector specifying treatment combinations which
will be considered as interactions.}

\item{inactive}{A character string defining the inactive treatment
component (see \code{\link{netcomb}}).}

\item{sep.comps}{A single character to define separator between
treatment components.}

\item{sep.ia}{A single character to define separator for interactions.}

\item{n}{A single number specifying the number of components in combinations.}
}
\value{
R function \code{createC} returns a combination matrix / C matrix with
studies in rows and component and interaction terms in columns.

R function \code{combinations} returns a character vector with combinations.
}
\description{
Auxiliary functions to (i) create a combination / C matrix with information
on treatment combinations and interaction terms and (ii) a vector with all
combinations in a component network meta-analysis.
}
\examples{
# Examples: example(netcomb)

}
\seealso{
\code{\link{netcomb}}, \code{\link{discomb}}
}
\author{
Guido Schwarzer \email{guido.schwarzer@uniklinik-freiburg.de},
  Gerta Rücker \email{gerta.ruecker@uniklinik-freiburg.de}
}
